context("canvasXpress Web Charts - Network")


test_that("cXnetwork1", {
    check_ui_test(cXnetwork1())
})

test_that("cXnetwork2", {
    check_ui_test(cXnetwork2())
})

test_that("cXnetwork3", {
    check_ui_test(cXnetwork3())
})

test_that("cXnetwork4", {
    check_ui_test(cXnetwork4())
})

test_that("cXnetwork5", {
    check_ui_test(cXnetwork5())
})

test_that("cXnetwork6", {
    check_ui_test(cXnetwork6())
})

test_that("cXnetwork7", {
    check_ui_test(cXnetwork7())
})

test_that("cXnetwork8", {
    check_ui_test(cXnetwork8())
})

test_that("cXnetwork9", {
    check_ui_test(cXnetwork9())
})

test_that("cXnetwork10", {
    check_ui_test(cXnetwork10())
})

test_that("cXnetwork11", {
    check_ui_test(cXnetwork11())
})

test_that("cXnetwork12", {
    check_ui_test(cXnetwork12())
})

test_that("cXnetwork13", {
    check_ui_test(cXnetwork13())
})
